@@ -35,10 +35,12 @@ class AlarmDisplayClock(clock.Clock):
         self.context.move_to(2, 16 if self.alarm_enabled else 26)
 
         h = self.time.hour
-        abrv = "AM"
         if self.twelve_hour_mode :
+            abrv = "AM"
             if h == 0 :
                 h = 12
+            elif h == 12 :
+                abrv = "PM"
             elif h > 12 :
                 h = h % 12
                 abrv = "PM"
@@ -80,11 +82,13 @@ class AlarmDisplayClock(clock.Clock):
             self.context.move_to(2, 35)
             self.context.set_source_rgb(1.0, 0.0, 0.0)
 
-            h = self.alarm_time.hour
-            abrv = "AM"
+            h = self.time.hour
             if self.twelve_hour_mode :
+                abrv = "AM"
                 if h == 0 :
                     h = 12
+                elif h == 12 :
+                    abrv = "PM"
                 elif h > 12 :
                     h = h % 12
                     abrv = "PM"
