@@ -34,10 +34,12 @@ class DecimalClock(clock.Clock):
         self.context.move_to(0, 35)
 
         h = self.time.hour
-        abrv = "AM"
         if self.twelve_hour_mode :
+            abrv = "AM"
             if h == 0 :
                 h = 12
+            elif h == 12 :
+                abrv = "PM"
             elif h > 12 :
                 h = h % 12
                 abrv = "PM"
