@@ -35,10 +35,12 @@ class TimeZoneClock(clock.Clock):
         self.context.move_to(2, 16 if self.time_zone is not None else 26)
 
         h = self.time.hour
-        abrv = "AM"
         if self.twelve_hour_mode :
+            abrv = "AM"
             if h == 0 :
                 h = 12
+            elif h == 12 :
+                abrv = "PM"
             elif h > 12 :
                 h = h % 12
                 abrv = "PM"
@@ -81,10 +83,12 @@ class TimeZoneClock(clock.Clock):
             self.context.move_to(2, 35)
 
             h = tz_time.hour
-            abrv = "AM"
             if self.twelve_hour_mode :
+                abrv = "AM"
                 if h == 0 :
                     h = 12
+                elif h == 12 :
+                    abrv = "PM"
                 elif h > 12 :
                     h = h % 12
                     abrv = "PM"
